body {
    padding-top: 70px;
}

#sidebar .list-group, #sidebar .list-group-item {
    background-color: transparent;
}

/* for list-groups nested within a list-group-item, reset the bottom margin */
.list-group-item > .list-group {
    margin-bottom: 0px;
}

/* for list-group-items nested within a list-group-item, reset the bottom
   padding of the last item, b/c the containing item has paddimg already 
 */
.list-group-item .list-group-item:last-child {
    padding-bottom: 0px;
}

.list-group-item {
    border: none;
}

.tag-0 {
    font-size: 16pt;
}

.tag-1 {
    font-size: 13pt;
}

.tag-2 {
    font-size: 10pt;
}

.tag-3 {
    font-size: 8pt;
}

.tag-4 {
    font-size: 6pt;
}

#aboutme {
    padding-top: 0px;
    padding-bottom: 5px;
    -ms-word-break: normal;
    word-break: normal;
}

#sidebar {
    padding-top: 0px;
    -ms-word-break: break-all;
    word-break: break-all;
    word-break: break-word;
    -webkit-hyphens: auto;
    -moz-hyphens: auto;
    -ms-hyphens: auto;
    hyphens: auto;
}

#sidebar a {
    color: inherit;
}

.icon-label {
    margin-left: 10px;
}

/* Example for how to control spacing between icon and label in specific
   lists in the sidebar. To change, override in your CUSTOM_CSS           */
#sidebar #social i {
    margin-right: 3px;
}

a, a:hover {
    color: inherit;
}

.entry-content a {
    text-decoration: none;
    border-bottom: 1px dotted;
}

.entry-content a:hover {
    text-decoration: none;
    border-bottom: 1px solid;
}

.entry-content img {
    max-width: 100%;
    height: auto;
}

.entry-content figcaption, .caption {
    font-size: small;
    margin-bottom: 2px;
}

.summary img {
    max-width: 100%;
    height: auto;
}


.floatright, .align-right {
    float: right;
}

.floatleft, .align-left {
    float: left;
}

.floatcenter, .align-center {
    display: block;
    margin-left: auto;
    margin-right: auto;
}

figure.floatright, .align-right {
    margin-left: 4px;
}

figure.floatleft, .align-left {
    margin-right: 4px;
}

figure.floatcenter, .align-center {
    margin-bottom: 11px;
}

.highlighttable pre {
    /* Removes bootstrap default margin-bottom */
    margin-bottom: 0px;
}

.highlighttable {
    /* Adds them margin-bottom to highlightable instead of <pre> */
    margin-bottom: 11px;
}

.highlighttable {
    width: 100%;
}

#categories ul, #tags ul {
    list-style: none;
    padding: 0;
    margin-left: 0;
}

.docutils.footnote td.label {
    display: table-cell;
    font-size: inherit;
    font-weight: inherit;
    line-height: inherit;
    color: inherit;
    text-align: inherit;
    white-space: inherit;
    border-radius: inherit;
}

.categories-timestamp {
    color: #AAAAAA;
    font-size: 0.9em;
    margin-right: 10px;
}

.tagcloud li {
    padding: 0px;
}
