{% extends 'base.html' %}

{% block title -%}
    Search &mdash; {{ super() }}
{%- endblock %}

{% block scripts %}
    {% if 'assets' in PLUGINS %}
    {% include 'includes/minify_tipuesearch.html' with context %}
    {% else %}
    <script type="text/javascript" src="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/tipuesearch/tipuesearch_set.js"></script>
    <script type="text/javascript" src="{{ SITEURL }}/{{ THEME_STATIC_DIR }}/tipuesearch/tipuesearch.min.js"></script>
    {% endif %}
    <script>
    $(document).ready(function() {
      $('#tipue_search_input').tipuesearch({
        'mode' : 'json',
        'show': 10,
        'newWindow': false,
        'contentLocation': 'tipuesearch_content.json'
      });
    });
    </script>
{% endblock %}

{% block content %}
<div id="tipue_search_content"></div>
{% endblock %}
