//
// Custom Additions -- Seafoam theme colours
// --------------------------------------------------
//


// Sidebar Vertical Navigation
// -------------------------
// from  http://www.jonathanbriehl.com/2014/01/17/vertical-menu-for-bootstrap-3/

@media (min-width: @screen-sm) {
  .sidebar-nav .navbar .navbar-collapse {
    padding: 0;
    max-height: none;
  }
  .sidebar-nav .navbar ul {
    float: none;
    display: block;
  }
  .sidebar-nav .navbar li {
    float: none;
    display: block;
  }
  .sidebar-nav .navbar li a {
    padding-top: 12px;
    padding-bottom: 12px;
  }
  .sidebar-nav {
	font-size: @font-size-large;
	font-family: @font-family-sans-serif;
  }
  .navbar-brand {
	height: auto;
	//min-height: 100%;
  }
}

@media (max-width: @screen-xs-max) {
  body {
    padding-top: 0;
  }
  
  .sidebar-nav {
    margin: -20px -15px 0 -15px;
	font-family: @font-family-sans-serif;
  }
}


// More Sidebar Nav
// -------------------------
//

.nav-list-level2 {
  font-size: @font-size-base;
  padding-left: 40px;
}

/* No top navigation */
body {
    padding-top: 20px   !important;
}

/* have links only below the header image */
.navbar-nonheader {
  clear: left;
}

/* make sidebar nav vertical */
/* modifications for our logo */

@media (max-width: 767px) {
  .navbar-header {
    margin-bottom: 45px;
  /*  This is too much if the screen is narrower than about 250px */
  }
}


// Images with Captions
// -------------------------
//

.max-col-md-9 {
	max-width: ((@screen-md - (@grid-gutter-width * 2)) * 9 / 12);
}


// Blog Archives page
.archives-date {
    text-align: right;
}

// Blog Featured Images
.featured-image {
  &:extend(.center-block);
  &:extend(.img-responsive);
  border-radius: @border-radius-base;
}

// Blog -- Project 365 EXIF data
.photo-infobox {
  &:extend(blockquote);
  padding-left: @font-size-h2 + @line-height-computed;
  em {
    font-style: normal;
    color: @brand-primary;
  }
  p:last-child {
    margin-bottom: 0;
  }
}
.photo-infobox::before {
  // displays 'exif', rotated, along the left edge of the box
  color: @blockquote-border-color;
  content: 'exif';
  display: block;
  font-size: @font-size-h2;
  font-style: italic;
  line-height: 1;
  position: absolute;
  transform: translate(@line-height-computed, 150px) rotate(-90deg);
  transform-origin: -2*@font-size-h2 top 0;
}

// Pager spacing
//
// On narrow screens, the two pages end up touching. This puts vertical space
// between them.
//
// TO-DO: Fix this further
.pager {
  a {
    margin-top: 12.5px;
    margin-bottom: 12.5px;
  }
  margin-top: 0;
  margin-bottom: 0;

}


// for Genealogy (Gigatrees)
// ------------------------
//

.gt-tab-table {
  &:extend(.table);
}


.gt-toc, 
#gt-menu,
.gt-stats-wrapper, 
.gt-heatmap-wrapper, 
.gt-census-wrapper, 
.gt-index-wrapper, 
.gt-birthdays-wrapper,
#map,
#gt-person-chart {
  &:extend(.well);
}

.gt-toc, 
#gt-menu,
.gt-stats-wrapper, 
.gt-index-wrapper, 
.gt-birthdays-wrapper,
#gt-person-chart {
  //padding: 10px 10px 10px 20px;
}
.gt-stats-wrapper  {
  //margin-bottom: 10px;
}

.gt-heatmap-wrapper {
  min-height:750px;
  padding: 3px 13px 5px 14px;
}

/* Photo and File link boxes */
.gt-image-photo-box {
  max-width: 100px;
  max-height: 100px;
  display: -moz-inline-box; 
  display: inline-block;
  overflow: hidden;
  border-radius: 4px;
  -webkit-border-radius: 4px;
  -moz-border-radius: 4px;
}
.gt-image-file-box {
  max-width: 50px;
  max-height: 50px;
  width: 50px;
  height: 50px;
  display: -moz-inline-box; 
  display: inline-block;
  overflow: hidden;
}
.gt-image-photo {
    max-height: 100%;
    max-width: 100%;
    display:block;
    margin-left:auto;
    margin-right:auto;
}
.gt-photo-thumb {
}
.gt-image-file {
    max-height: 100%;
    max-width: 100%;
    width: 50px;
    height: 50px;
    display:block;
    margin-left:auto;
    margin-right:auto;   
}

/* General */
.gt-aid                        {font-family:@font-family-monospace; font-size:.9em;}  //font-family:Monaco, Consolas, monospace
.gt-alignright                 {float:right;}
.gt-alignleft                  {/*float:left; position:absolute;*/}
/* Index Page  */
#gt-menu h3                    {padding:5px; font-weight:700;}  //bold
#gt-menu ul                    {padding: 0; margin: 0; border: 0; list-style: none;}
#gt-menu ul li                 {background: transparent;}  //border-bottom: 1px solid rgba(196, 196, 196, 0.25);
#gt-menu a                     {color:@text-color-inverse; border-bottom:none;}  //#282828
#gt-menu a:link                {color:@text-color-inverse;}  //#282828
#gt-menu a:visited             {color:@text-color-inverse;}  //#282828
#gt-menu a:active              {color:@text-color-inverse;}  //#282828
#gt-menu a:hover               {color:@link-color; text-decoration:none;}  //#9e9e9e
.gt-toc-item                   {}

/* Surnames Page */
.gt-index-legend               {text-align:center;}
.gt-index-names                {text-align:center;}
.gt-index-entry                {display:inline; white-space:nowrap;}
/* Bonkers Page */
.gt-bonkers                    {background:@well-bg; color:@text-color-inverse; font-size:@font-size-small; padding-top:5px;}  // no backgound, font-size:12px
/* Photos Page */
#gt-photos                     {background:@well-bg; color:@text-color-inverse; padding: 3px 3px 0px 3px;}  //no background
/* Updates page */
.gt-updated-missing            {background:@well-bg; color:@text-color-inverse;}
.gt-updated-person             {background:@well-bg; color:@text-color-inverse;}
.gt-updated-note               {background:@well-bg; color:@text-color-inverse; font-style:italic;}
.gt-updated-source             {background:@well-bg; color:@text-color-inverse; font-style:italic;}
/* Source Page */
.gt-source-publication         {background:mix(@well-bg, @sol-green);}  //#F0FFF0
.gt-source-bibliography        {background:mix(@well-bg, @sol-yellow);}  //#F4E5CF
.gt-source-template            {background:@well-bg; color:@text-color-inverse;}  //#FFFAFA
.gt-source-type                {background:mix(@well-bg, @sol-green);}  //#F0FFF0
.gt-source-repository          {background:mix(@well-bg, @sol-green);}  //#F0FFF0
.gt-source-quality             {background:mix(@well-bg, @sol-red);}  //#F4E5CF
.gt-source-page                {background:mix(@well-bg, @sol-red);}  //#F4E5CF
.gt-source-ref                 {white-space:nowrap;}
.gt-referrer                   {background:mix(@well-bg, @sol-green);}  //#F0FFF0
.gt-url                        {background:mix(@well-bg, @sol-purple);}  //#CBCCE6
.gt-citation-heading           {background:mix(@well-bg, @body-bg); padding:1px 10px 2px 10px;}  //#959A92
.gt-citation-text              {background:mix(@well-bg, @sol-blueDark);}  //#E7F0FF
.gt-citation-text-missing      {padding: 0;}
.gt-citation-text pre          {margin: 5px 0px;}
/* Location Page */
.gt-location                   {background:mix(@well-bg, @sol-blueDark); padding:5px 10px 5px 10px;}  //#E7F0FF
.gt-table-box                  {width:100%; border:1px solid #aaa; border-spacing:0px; border-collapse:separate; border-radius: 4px 4px 4px 4px; -webkit-border-radius: 4px 4px 4px 4px; -moz-border-radius: 4px 4px 4px 4px; /*padding-bottom: 1px;*/}
/* Statistics Page */
.gt-bonkers-item               {background:@well-bg; border-radius: 5px; -webkit-border-radius: 5px; color:@text-color-inverse; margin-bottom:20px; padding-left:10px; padding-right:10px; padding-bottom:10px;}  //background:white
.gt-il-title                   {padding-left:10px; padding-top:10px; background:@brand-primary; color:@text-color; font-family:@font-family-sans-serif; font-weight:500; min-height:30px; vertical-align:bottom;}  //background:white; bold
.gt-il-item                    {padding-left:10px;}
.gt-il-item-bonkers            {font-size: 1.4em; padding: 10px 0;}
.gt-stats-title                {font-weight: 700; padding-bottom: 10px;}  //bold
.gt-stats-line                 {padding-left: 20px;}
.gt-stats-table                {border: 1px;}
.gt-stats-table-line           {}
.gt-stats-line tr td           {padding-right: 10px;}
.gt-stats-legend td            {font-weight: 700;}  //bold
.gt-stats-super-legend td      {font-weight: bolder; text-align: center;}
/* Census page */
.gt-census                     {width:100%; background:lightgrey; padding:1px 1px 1px 1px; border: 1px solid rgba(196, 196, 196, 0.25);}
.gt-census i                   {font-style:italic;}
.gt-census b                   {font-weight:700;}  //bold
.gt-census-heading             {background:#FFE7BA; font-weight:700;}  //bold
.gt-census-body                {background:lightyellow;}
.gt-census-name                {background:lightyellow; vertical-align:top; white-space:nowrap;}
.gt-census-date                {background:lightyellow; vertical-align:top; white-space:nowrap;}
.gt-census-entryeven           {background:lightyellow; vertical-align:top; white-space:nowrap; text-align:center;}
.gt-census-entryodd            {background:lightgrey;   vertical-align:top; white-space:nowrap; text-align:center;}
/* Immigrants Page */
.gt-immigrant-ship             {font-style:italic;}
/* Nobility Titles Page */
.gt-title-new                  {}
.gt-title-cont                 {}

/* Product Version */
//.gt-version                    {font-size:.9em; padding-top:10px; padding-bottom:10px;}  //unsed
#gt-qscore                     {display:none;}
/* Last Modified date */
#gt-modified                   {font-size:@font-size-small; padding: 2px 0px 0px 0px; margin-top: 20px;}  //font-size:.9em; padding: 2px 0px 0px 0px;
/* GEDCOM ids */
.gt-heading                    {background:@body-bg; color:@sol-white;}  //background:#303030, color:white
.gt-heading li.gt-title        {float:left; color:@sol-white;}  //white
.gt-heading li.gt-id           {float:right;}
/* Photos */ 
.gt-photo                      {}
/* Claims */
.gt-name                       {background:mix(@well-bg, @sol-purple);}  //E7D0FF
.gt-parents                    {background:mix(@well-bg, @sol-red);}  //#EDCBAD
.gt-spouses                    {background:@well-bg; color:@text-color-inverse;}  //#FFEAD0
.gt-children                   {background:mix(@well-bg, @sol-blueDark);}  //#E7F0FF
.gt-assoc                      {background:#EDCBAD;}
.gt-event                      {background:@well-bg; color:@text-color-inverse;}  //#E7F0FF
.gt-attr                       {background:@well-bg; color:@text-color-inverse;}  //#E7F0FF
.gt-claim>td                   {padding-right:1em;}
.gt-claim-index                {padding:0px 5px 0px 0px;}
.gt-claim-name                 {}  //white-space:nowrap;
.gt-claim-tag                  {white-space:normal;}
.gt-claim-tag-no-wrap          {white-space:nowrap;}
.gt-claim-data                 {}
.gt-claim-date                 {white-space:nowrap; text-align:right;}
.gt-claim-age                  {white-space:nowrap;}
.gt-claim-disproved            {background:lightgrey;}
.gt-claim-quality              {text-align:right; white-space: nowrap;}
.gt-claim-quality-disproved    {background:lightgrey; font-weight:700;}  //bold
.gt-claim-quality-uncertain    {color:@sol-black;}  //black
.gt-claim-quality-estimated    {color:@sol-purple;}  //purple
.gt-claim-quality-unsupported  {color:@sol-black;}  //black
.gt-claim-quality-improbable   {color:@sol-red;  font-weight:700;}  //red
.gt-claim-quality-probable     {color:@sol-green;}  //green
.gt-claim-quality-proposed     {color:@sol-blueDark;}  //#28A500
.gt-claim-quality-possible     {color:@sol-blueDark;}  //#28A500
.gt-claim-quality-supported    {color:@sol-blueDark;}  //#28A500
.gt-claim-quality-likely       {color:@sol-blueDark;}  //#28A500
.gt-claim-quality-maybe        {color:@sol-blueDark;}  //#28A500
.gt-claim-quality-assumed      {color:@sol-blueDark;}  //#28A500
.gt-claim-quality-proven       {color:@sol-blue;}  //blue
.gt-claim-quality-certain      {color:@sol-blue;}  //blue
.gt-claim-evidence             {color:@sol-green;}  //green
.gt-claim-evidence a           {color:@sol-green;}  //green
.gt-claim-evidence a:link      {color:@sol-green;}  //green
.gt-claim-evidence a:visited   {color:@sol-green;}  //green
.gt-claim-evidence a:active    {color:@sol-green;}  //green
.gt-claim-conclusion           {color:@sol-purple;}  //purple
.gt-claim-conclusion a         {color:@sol-purple;}  //purple
.gt-claim-conclusion a:link    {color:@sol-purple;}  //purple
.gt-claim-conclusion a:visited {color:@sol-purple;}  //purple
.gt-claim-conclusion a:active  {color:@sol-purple;}  //purple
/* Links */
.gt-source-link                {background:@well-bg; color:@text-color-inverse;} //empty
.gt-article-link               {}
.gt-location-link              {color:#1a4c80;}
//.gt-name-link                  {color:#cc3300; white-space:normal;}
.gt-chart-name-link            {color:#00008b;}
.gt-chart-name-link a          {border-bottom-width: 0;}
/* Text */
.gt-comment                    {background:mix(@well-bg, @sol-yellow);}  //#FFFFCC
.gt-note-text                  {background:mix(@well-bg, @sol-blueDark); padding:5px 10px 3px 10px;}  //#E7F0FF
/* Tabs Content */
.gt-list-group                 {border-radius: 0 0 @border-radius-base @border-radius-base; margin: 0;} 
.gt-list-item                  {position: relative; display: block; padding: 5px 10px 8px 15px; margin-bottom: -1px; border: 1px solid #ddd;} 
.gt-list-item:last-child       {margin-bottom: 0;}
/* Maps */
#map                           {min-height:750px; padding: 10px 10px 10px 10px;}
.gt-map                        {padding:0px 0px 0px 00px;}
#gt-map-canvas                 {height: 500px;}
#gt-heat-map                   {width:100%; max-width:1023px; height:650px; margin-right:10px; float:left; border: 1px solid rgba(196, 196, 196, 0.25);}
div.infowindow                 {max-height:400px; width: 100%; max-width:400px; overflow-y:auto; overflow-x: hidden;} /* for use with google heat map */
.gt-map-location               {white-space:nowrap;}
.gt-map-person                 {white-space:nowrap;}
.gt-map-status                 {display: inline-block; max-width:1024px; width:auto; margin:15px 0 15px 0;}
/* Ancestor Lists */
.gt-al-page                    {background:@well-bg; color:@text-color-inverse; padding:5px; border: 1px solid #aaa; margin: 2px 0px 20px 0px; border-radius: 4px 4px 4px 4px; -webkit-border-radius: 4px 4px 4px 4px; -moz-border-radius: 4px 4px 4px 4px;}  //background:#E0FFFF
.gt-al-page b                  {font-weight:700;}  //bold
.gt-al-page i                  {font-style:italic;}
.gt-al-legend                  {width:600px; list-style-type:none; margin:0; padding:0;}
.gt-al-generation              {padding-top:10px; font-weight:700;}  //bold
.gt-al-list                    {list-style-type:none;  margin:0; padding:0; width: 100%;}
.gt-al-item                    {}
.gt-al-item-primary            {font-weight:700;}  //bold
.gt-al-item-uncertain          {background:lightgrey;}
.gt-al-name                    {float:left;  margin:0;}
.gt-al-path                    {float:right; margin:0;}
/* Note and Articles */
.gt-note-text img, .gt-url img {cursor:pointer; margin:0 0 3px; background-color:#fff; border:1px solid #ccc; padding:2px; -moz-border-radius:4px; -webkit-border-radius:4px;}
.gt-note-text img              {max-height: 100%; max-width: 100%; margin:auto; display:block; }
/* Charts */
#gt-person-chart               {position:relative;}
.gt-chart-node                 {padding:2px; text-align:left; font-size:8pt; font-family:@font-family-serif; vertical-align:middle; border-top-width:1px; border-right-width:1px; border-bottom-width:1px; border-left-width:1px; border-top-style:solid; border-right-style:solid; border-bottom-style:solid; border-left-style:solid; border-top-color:rgb(0, 0, 0); border-right-color:rgb(0, 0, 0); border-bottom-color:rgb(0, 0, 0); border-left-color:rgb(0, 0, 0); border-image:initial;}  //font-family:Arial, Helvetica, sans-serif;
.gt-chart-node                 {position:absolute; z-index:5; overflow:hidden; height:36px; width:156px; border-color: #949494; -moz-border-radius:5px; -webkit-border-radius:5px; border-radius:5px; -khtml-border-radius:5px;}
.gt-chart-nodeshadow           {position:absolute; z-index:1; overflow:hidden; height:33px; width:153px; background-color:#444; -moz-border-radius:5px; -webkit-border-radius:5px; border-radius:5px; -khtml-border-radius:5px;}
.gt-chart-connector            {position:absolute; z-index:3; overflow:hidden; background-color:#949494;}
.gt-chart-arrow                {position:absolute; z-index:5;}
.gt-chart-arrow img            {/*width:10px;  height:10px;*/ cursor:pointer; margin:0 0 5px; background-color:#fff; border:1px solid #ccc; padding:2px; -moz-border-radius:4px; -webkit-border-radius:4px;}
.gt-chart-node-bkgnd5          {background-color:#f5ecce;}
.gt-chart-node-bkgnd4          {background-color:#f7f2e0;}
.gt-chart-node-bkgnd3          {background-color:#fbf8ef;}
.gt-chart-node-bkgnd2          {background-color:#fbfbef;}
.gt-chart-node-bkgnd1          {background-color:#ffffff;}
.gt-chart-node-bkgnd0          {background-color:#f5ecce;}
#gt-chart-legend-uncertain     {background-color:#aaaaaa; border:1px solid #666;}
.gt-chart-node-uncertain       {background-color:#aaaaaa;}
.gt-chart-node-uncertain a     {color:#ffffff;}
.gt-chart-node-unknown         {background-color:#efefef;}
.gt-chart-arrow0               {left:  4px;}
.gt-chart-node0                {left: 23px;}
.gt-chart-nodeshadow0          {left: 27px;}
.gt-chart-connector0a          {left:179px; height:1px; width:5px;}
.gt-chart-connector0b          {left:183px; height:1px; width:5px;}
.gt-chart-connector0c          {left:183px; height:40px; width:1.1px;}
#gt-chart-arrow2               {top:290px; left:320px; width:16px; height:10px;}
#gt-chart-arrow3               {top:350px; left:320px; width:16px; height:10px;}
#gt-chart-node1                {top:310px; left:188px;}
#gt-chart-nodeshadow1          {top:314px; left:192px;}
#gt-chart-connector1           {top:328px; left:344px; height:  1px; width:5px;}
#gt-chart-connector1-2a        {top:168px; left:348px; height:160px; width:1.1px;}
#gt-chart-connector1-2b        {top:168px; left:348px; height:  1px; width:5px;}
#gt-chart-connector1-3a        {top:328px; left:348px; height:160px; width:1.1px;}
#gt-chart-connector1-3b        {top:488px; left:348px; height:  1px; width:5px;}
#gt-chart-node2                {top:150px; left:353px;}
#gt-chart-nodeshadow2          {top:154px; left:357px;}
#gt-chart-connector2           {top:168px; left:509px; height: 1px; width:5px;}
#gt-chart-connector2-4a        {top: 88px; left:513px; height:80px; width:1.1px;}
#gt-chart-connector2-4b        {top: 88px; left:513px; height: 1px; width:5px;}
#gt-chart-connector2-5a        {top:168px; left:513px; height:80px; width:1.1px;}
#gt-chart-connector2-5b        {top:248px; left:513px; height: 1px; width:5px;}
#gt-chart-node3                {top:470px; left:353px;}
#gt-chart-nodeshadow3          {top:474px; left:357px;}
#gt-chart-connector3           {top:488px; left:509px; height:  1px; width:5px;}
#gt-chart-connector3-6a        {top:408px; left:513px; height: 80px; width:1.1px;}
#gt-chart-connector3-6b        {top:408px; left:513px; height:  1px; width:5px;}
#gt-chart-connector3-7a        {top:488px; left:513px; height: 80px; width:1.1px;}
#gt-chart-connector3-7b        {top:568px; left:513px; height:  1px; width:5px;}
#gt-chart-node4                {top: 70px; left:518px;}
#gt-chart-nodeshadow4          {top: 74px; left:522px;}
#gt-chart-connector4           {top: 88px; left:674px; height:1px; width:5px;}
#gt-chart-connector4-8a        {top: 48px; left:678px; height:40px; width:1.1px;}
#gt-chart-connector4-8b        {top: 48px; left:678px; height:1px; width:5px;}
#gt-chart-connector4-9a        {top: 88px; left:678px; height:40px; width:1.1px;}
#gt-chart-connector4-9b        {top:128px; left:678px; height:1px; width:5px;}
#gt-chart-node5                {top:230px; left:518px;}
#gt-chart-nodeshadow5          {top:234px; left:522px;}
#gt-chart-connector5           {top:248px; left:674px; height:1px; width:5px;}
#gt-chart-connector5-10a       {top:208px; left:678px; height:40px; width:1.1px;}
#gt-chart-connector5-10b       {top:208px; left:678px; height:1px; width:5px;}
#gt-chart-connector5-11a       {top:248px; left:678px; height:40px; width:1.1px;}
#gt-chart-connector5-11b       {top:288px; left:678px; height:1px; width:5px;}
#gt-chart-node6                {top:390px; left:518px;}
#gt-chart-nodeshadow6          {top:394px; left:522px;}
#gt-chart-connector6           {top:408px; left:674px; height:1px; width:5px;}
#gt-chart-connector6-12a       {top:368px; left:678px; height:40px; width:1.1px;}
#gt-chart-connector6-12b       {top:368px; left:678px; height:1px; width:5px;}
#gt-chart-connector6-13a       {top:408px; left:678px; height:40px; width:1.1px;}
#gt-chart-connector6-13b       {top:448px; left:678px; height:1px; width:5px;}
#gt-chart-node7                {top:550px; left:518px;}
#gt-chart-nodeshadow7          {top:554px; left:522px;}
#gt-chart-connector7           {top:568px; left:674px; height:1px; width:5px;}
#gt-chart-connector7-14a       {top:528px; left:678px; height:40px; width:1.1px;}
#gt-chart-connector7-14b       {top:528px; left:678px; height:1px; width:5px;}
#gt-chart-connector7-15a       {top:568px; left:678px; height:40px; width:1.1px;}
#gt-chart-connector7-15b       {top:608px; left:678px; height:1px; width:5px;}
#gt-chart-node8                {top: 30px; left:683px;}
#gt-chart-nodeshadow8          {top: 34px; left:687px;}
#gt-chart-connector8           {top: 48px; left:839px; height:1px; width:5px;}
#gt-chart-connector8-16a       {top: 28px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector8-16b       {top: 28px; left:843px; height:1px; width:5px;}
#gt-chart-connector8-17a       {top: 48px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector8-17b       {top: 68px; left:843px; height:1px; width:5px;}
#gt-chart-node9                {top:110px; left:683px;}
#gt-chart-nodeshadow9          {top:114px; left:687px;}
#gt-chart-connector9           {top:128px; left:839px; height:1px; width:5px;}
#gt-chart-connector9-18a       {top:108px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector9-18b       {top:108px; left:843px; height:1px; width:5px;}
#gt-chart-connector9-19a       {top:128px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector9-19b       {top:148px; left:843px; height:1px; width:5px;}
#gt-chart-node10               {top:190px; left:683px;}
#gt-chart-nodeshadow10         {top:194px; left:687px;}
#gt-chart-connector10          {top:208px; left:839px; height:1px; width:5px;}
#gt-chart-connector10-20a      {top:188px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector10-20b      {top:188px; left:843px; height:1px; width:5px;}
#gt-chart-connector10-21a      {top:208px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector10-21b      {top:228px; left:843px; height:1px; width:5px;}
#gt-chart-node11               {top:270px; left:683px;}
#gt-chart-nodeshadow11         {top:274px; left:687px;}
#gt-chart-connector11          {top:288px; left:839px; height:1px; width:5px;}
#gt-chart-connector11-22a      {top:268px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector11-22b      {top:268px; left:843px; height:1px; width:5px;}
#gt-chart-connector11-23a      {top:288px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector11-23b      {top:308px; left:843px; height:1px; width:5px;}
#gt-chart-node12               {top:350px; left:683px;}
#gt-chart-nodeshadow12         {top:354px; left:687px;}
#gt-chart-connector12          {top:368px; left:839px; height:1px; width:5px;}
#gt-chart-connector12-24a      {top:348px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector12-24b      {top:348px; left:843px; height:1px; width:5px;}
#gt-chart-connector12-25a      {top:368px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector12-25b      {top:388px; left:843px; height:1px; width:5px;}
#gt-chart-node13               {top:430px; left:683px;}
#gt-chart-nodeshadow13         {top:434px; left:687px;}
#gt-chart-connector13          {top:448px; left:839px; height:1px; width:5px;}
#gt-chart-connector13-26a      {top:428px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector13-26b      {top:428px; left:843px; height:1px; width:5px;}
#gt-chart-connector13-27a      {top:448px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector13-27b      {top:468px; left:843px; height:1px; width:5px;}
#gt-chart-node14               {top:510px; left:683px;}
#gt-chart-nodeshadow14         {top:514px; left:687px;}
#gt-chart-connector14          {top:528px; left:839px; height:1px; width:5px;}
#gt-chart-connector14-28a      {top:508px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector14-28b      {top:508px; left:843px; height:1px; width:5px;}
#gt-chart-connector14-29a      {top:528px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector14-29b      {top:548px; left:843px; height:1px; width:5px;}
#gt-chart-node15               {top:590px; left:683px;}
#gt-chart-nodeshadow15         {top:594px; left:687px;}
#gt-chart-connector15          {top:608px; left:839px; height:1px; width:5px;}
#gt-chart-connector15-30a      {top:588px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector15-30b      {top:588px; left:843px; height:1px; width:5px;}
#gt-chart-connector15-31a      {top:608px; left:843px; height:20px; width:1.1px;}
#gt-chart-connector15-31b      {top:628px; left:843px; height:1px; width:5px;}
#gt-chart-node16               {top: 10px; left:848px;}
#gt-chart-nodeshadow16         {top: 14px; left:852px;}
#gt-chart-arrow16              {top: 19px; left:1010px;}
#gt-chart-node17               {top: 50px; left:848px;}
#gt-chart-nodeshadow17         {top: 54px; left:852px;}
#gt-chart-arrow17              {top: 69px; left:1010px;}
#gt-chart-node18               {top: 90px; left:848px;}
#gt-chart-nodeshadow18         {top: 94px; left:852px;}
#gt-chart-arrow18              {top: 99px; left:1010px;}
#gt-chart-node19               {top:130px; left:848px;}
#gt-chart-nodeshadow19         {top:134px; left:852px;}
#gt-chart-arrow19              {top:139px; left:1010px;}
#gt-chart-node20               {top:170px; left:848px;}
#gt-chart-nodeshadow20         {top:174px; left:852px;}
#gt-chart-arrow20              {top:179px; left:1010px;}
#gt-chart-node21               {top:210px; left:848px;}
#gt-chart-nodeshadow21         {top:214px; left:852px;}
#gt-chart-arrow21              {top:219px; left:1010px;}
#gt-chart-node22               {top:250px; left:848px;}
#gt-chart-nodeshadow22         {top:254px; left:852px;}
#gt-chart-arrow22              {top:259px; left:1010px;}
#gt-chart-node23               {top:290px; left:848px;}
#gt-chart-nodeshadow23         {top:294px; left:852px;}
#gt-chart-arrow23              {top:299px; left:1010px;}
#gt-chart-node24               {top:330px; left:848px;}
#gt-chart-nodeshadow24         {top:334px; left:852px;}
#gt-chart-arrow24              {top:339px; left:1010px;}
#gt-chart-node25               {top:370px; left:848px;}
#gt-chart-nodeshadow25         {top:374px; left:852px;}
#gt-chart-arrow25              {top:379px; left:1010px;}
#gt-chart-node26               {top:410px; left:848px;}
#gt-chart-nodeshadow26         {top:414px; left:852px;}
#gt-chart-arrow26              {top:419px; left:1010px;}
#gt-chart-node27               {top:450px; left:848px;}
#gt-chart-nodeshadow27         {top:454px; left:852px;}
#gt-chart-arrow27              {top:459px; left:1010px;}
#gt-chart-node28               {top:490px; left:848px;}
#gt-chart-nodeshadow28         {top:494px; left:852px;}
#gt-chart-arrow28              {top:499px; left:1010px;}
#gt-chart-node29               {top:530px; left:848px;}
#gt-chart-nodeshadow29         {top:534px; left:852px;}
#gt-chart-arrow29              {top:539px; left:1010px;}
#gt-chart-node30               {top:570px; left:848px;}
#gt-chart-nodeshadow30         {top:574px; left:852px;}
#gt-chart-arrow30              {top:579px; left:1010px;}
#gt-chart-node31               {top:610px; left:848px;}
#gt-chart-nodeshadow31         {top:614px; left:852px;}
#gt-chart-arrow31              {top:619px; left:1010px;}

/******************/
/* Tabs           */
/******************/
#gt-profile-tab,
#gt-timeline-tab,
#gt-attributes-tab,
#gt-ancestors-tab,
#gt-chart-tab {
}

.gt-ac-container label[for^='gt-ac']{
  background-color: @brand-primary;
  cursor: pointer;
  border-radius: @border-radius-base @border-radius-base 0 0;
  display: block;
  font-weight: 700;
  padding: 5px 15px;
  margin-bottom: 0; // override bootstrap
}
.gt-ac-container label[for^='gt-ac']:hover{
  background: lighten(@brand-primary, 10%);;
}



.gt-ac-container{
  margin: 5px auto 30px auto;
  text-align: left;
}

.gt-ac-container label:hover:after, 
.gt-ac-container input:checked + label:hover:after {
    background: transparent url(../images/ac_arrow_down.png) no-repeat center center;
}
.gt-ac-container input:checked + label:hover:after {
    background-image: url(../images/ac_arrow_up.png);
}    

/*
.gt-ac-container label[for^='gt-ac']{
  font-family: 'Roboto Condensed', 'Arial Narrow', Arial, sans-serif;
  padding: 5px 15px;
  margin-bottom: 0px; /* override bootstrap */ /*
  position: relative;
  display: block;
  height: 40px;
  cursor: pointer;
  color: #333;
  line-height: 33px;
  font-size: 19px;
  font-weight:normal;
  background: #ffffff;
  background: -moz-linear-gradient(top, #ffffff 1%, #eaeaea 100%);
  background: -webkit-gradient(linear, left top, left bottom, color-stop(1%,#ffffff), color-stop(100%,#eaeaea));
  background: -webkit-linear-gradient(top, #ffffff 1%,#eaeaea 100%);
  background: -o-linear-gradient(top, #ffffff 1%,#eaeaea 100%);
  background: -ms-linear-gradient(top, #ffffff 1%,#eaeaea 100%);
  background: linear-gradient(top, #ffffff 1%,#eaeaea 100%);
  filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#ffffff', endColorstr='#eaeaea',GradientType=0 );
  box-shadow:
    0px 0px 0px 1px rgba(155,155,155,0.3),
    1px 0px 0px 0px rgba(255,255,255,0.9) inset,
    0px 2px 2px rgba(0,0,0,0.1);
}
.gt-ac-container label[for^='gt-ac']:hover{
  background: #fff;
  font-weight: 500;
}
.gt-ac-container input[id^="gt-ac-"]:checked + label,
.gt-ac-container input[id^="gt-ac-"]:checked + label:hover{
    background: #96b432;
    background: -moz-linear-gradient(top, #96b432 0, #92b42a 3%, #8fb429 9%, #8eb12f 12%, #8db12b 15%, #88ad29 24%, #7fa629 41%, #759d23 56%, #679320 79%, #64911a 85%, #648e22 88%, #638d1d 91%, #5e8d1d 97%, #64891f 100%);
    background: -webkit-gradient(linear, left top, left bottom, color-stop(0%, #96b432), color-stop(3%, #92b42a), color-stop(9%, #8fb429), color-stop(12%, #8eb12f), color-stop(15%, #8db12b), color-stop(24%, #88ad29), color-stop(41%, #7fa629), color-stop(56%, #759d23), color-stop(79%, #679320), color-stop(85%, #64911a), color-stop(88%, #648e22), color-stop(91%, #638d1d), color-stop(97%, #5e8d1d), color-stop(100%, #64891f));
    background: -webkit-linear-gradient(top, #96b432 0, #92b42a 3%, #8fb429 9%, #8eb12f 12%, #8db12b 15%, #88ad29 24%, #7fa629 41%, #759d23 56%, #679320 79%, #64911a 85%, #648e22 88%, #638d1d 91%, #5e8d1d 97%, #64891f 100%);
    background: -o-linear-gradient(top, #96b432 0, #92b42a 3%, #8fb429 9%, #8eb12f 12%, #8db12b 15%, #88ad29 24%, #7fa629 41%, #759d23 56%, #679320 79%, #64911a 85%, #648e22 88%, #638d1d 91%, #5e8d1d 97%, #64891f 100%);
    background: -ms-linear-gradient(top, #96b432 0, #92b42a 3%, #8fb429 9%, #8eb12f 12%, #8db12b 15%, #88ad29 24%, #7fa629 41%, #759d23 56%, #679320 79%, #64911a 85%, #648e22 88%, #638d1d 91%, #5e8d1d 97%, #64891f 100%);
    background: linear-gradient(top, #96b432 0, #92b42a 3%, #8fb429 9%, #8eb12f 12%, #8db12b 15%, #88ad29 24%, #7fa629 41%, #759d23 56%, #679320 79%, #64911a 85%, #648e22 88%, #638d1d 91%, #5e8d1d 97%, #64891f 100%);
  color: #fff;
  text-shadow: 0px 1px 1px rgba(255,255,255, 0.3);
  box-shadow:
    0px 0px 0px 1px rgba(155,155,155,0.3),
    0px 2px 2px rgba(0,0,0,0.1);
}
.gt-ac-container label[for^='gt-ac']:hover:after,
.gt-ac-container input[id^="gt-ac-"]:checked + label:hover:after{
  content: '';
  position: absolute;
  width: 24px;
  height: 24px;
  right: 13px;
  top: 7px;
} */
.gt-ac-container input[id^="gt-ac-"] {
  display: none;
}
.gt-ac-container article{
  background: rgba(255, 255, 255, 0.5);
  margin-top: -1px;
  overflow: hidden;
  height: 0px;
  position: relative;
  -webkit-transition: height 0.3s ease-in-out, box-shadow 0.6s linear;
  -moz-transition: height 0.3s ease-in-out, box-shadow 0.6s linear;
  -o-transition: height 0.3s ease-in-out, box-shadow 0.6s linear;
  -ms-transition: height 0.3s ease-in-out, box-shadow 0.6s linear;
  transition: height 0.3s ease-in-out, box-shadow 0.6s linear;
}

.gt-ac-container article p{
  color: @text-color-inverse;  //#777
  line-height: floor((@font-size-small * @line-height-base));  //23px
  font-size: @font-size-small;  //14px
  margin: 0px;
  padding-top: 10px;
  text-shadow: 1px 1px 1px rgba(255,255,255,0.3);
}
.gt-ac-container input[id^="gt-ac-"]:checked ~ article{
  -webkit-transition: height 0.5s ease-in-out, box-shadow 0.1s linear;
  -moz-transition: height 0.5s ease-in-out, box-shadow 0.1s linear;
  -o-transition: height 0.5s ease-in-out, box-shadow 0.1s linear;
  -ms-transition: height 0.5s ease-in-out, box-shadow 0.1s linear;
  transition: height 0.5s ease-in-out, box-shadow 0.1s linear;
  box-shadow: 0px 0px 0px 1px rgba(155,155,155,0.3);
}

.gt-ac-container input[id^="gt-ac-"]:checked ~ article.gt-ac-auto {height: auto; overflow: visible; margin-bottom:20px;} 

.gt-ac-container input[id^="gt-ac-"]:checked  + label {margin-top: 20px;} 

/******************/
/* Graphs         */
/******************/
#boysNamesChartContainer          {height: 500px;}
#girlsNamesChartContainer         {height: 500px;}
#surnamesChartContainer           {height: 500px;} 
#totRecordsChartContainer         {height: 200px;}
#expandedTotRecordsChartContainer {height: 400px;}
#avgRecordsChartContainer         {height: 200px;}
#distOfClaimsChartContainer       {height: 400px; margin-left:20px;}
#docClaimsChartContainer          {height: 400px;}
#avgLifeSpanChartContainer        {height: 600px;}
#avgAgesChartContainer            {height: 150px;}

#expandedTotRecordsChartContainer2 {height: 600px;}

#xfactorChartContainer             {height: 350px;}
#xfactorTotRecordsChartContainer   {height: 300px;}
#xfactorStatsChartContainer        {height: 300px;}

@media only screen and (max-width:1200px) { 
  g.dxc-title g text tspan {font-size: .7em;}
}

/********************/
/* Mobile Overrides */
/********************/

@media only screen and (max-width: 1200px) {
  .gt-census-wrapper {font-size: 1.0em;}
}

@media only screen and (max-width: 1120px) {
  #gt-chart-tab {display:none;}
}

@media only screen and (max-width: 992px) {
  .gt-al-path        {display:none;}
  .gt-census-wrapper {font-size: .7em;}
}

@media only screen and (max-width: 768px) {
  #gt-ancestors-tab  {display:none;}
  .gt-census-wrapper {font-size: .6em;}
  .gt-claim-quality  {text-align:left;}
  .gt-claim-date     {text-align:left;}
  #gt-comments       {padding: 5px 5px;}
}

/********************/
/*Overrides         */
/********************/

//.entry-content {
.fake-list {
  ul {
    padding-left: 0;
    list-style: none;
  }
}
.gt-chart-name-link          {border-bottom: none;}
.real-list {
  ul {
    list-style:   disc outside none;
    padding-left: 25px;
  }
}
.gt-revision                   {background:@well-bg; color:@text-color-inverse; font-size:@font-size-base;}

// links within labels, panels
.label-default,
.label-primary,
.panel-primary {
  a {
    color: @text-color;
  }
}
