{% extends "article_list.html" %}

{% block title -%}
    Articles by {{ author }} &mdash; {{ super() }}
{%- endblock %}

{% block breadcrumbs %}
    {% if DISPLAY_BREADCRUMBS %}
        <ol class="breadcrumb">
            <li><a href="{{ SITE_ROOT_URL }}" title="{{ SITENAME }}"><span class="fa fa-home fa-lg"></span></a></li>
	        {% if MENUITEMS_2_AT %}
	            <li><a href="{{ SITEURL }}/{{ MENUITEMS_2_AT_LINK }}" title="{{ MENUITEMS_2_AT }}">{{ MENUITEMS_2_AT }}</a></li>
	        {% endif %}
            <li><a href="{{ SITEURL }}/{{ AUTHORS_URL|default('authors.html') }}" title="Authors">Authors</a></li>
            <li class="active">{{ AUTHOR }}</li>
        </ol>
    {% endif %}
{% endblock %}
