// Google Custom Search
// -------------------------
//

.gsc-control-cse {
	font-family: @font-family-base !important;
	font-size: @font-size-base !important;
	border: none !important;
	padding: 0 !important;
}

// can't seem to change the search results body font...

.gsc-input {
	color: @text-color-inverse;
}
input .gsc-search-button {
	.btn;
	.btn-primary;
}
input.gsc-search-button {
	color: @text-color !important;
}
.gsc-adblock {
	color: @text-color-inverse;
}
.gs-webResult .gs-snippet,
.gs-imageResult .gs-snippet,
.gs-fileFormatType {
	color: @text-color !important;
}
.gs-result .gs-title,
.gs-result .gs-title * {
	text-decoration: none !important;
}
.cse .gsc-webResult.gsc-result,
.gsc-webResult.gsc-result,
.gsc-imageResult-column,
.gsc-imageResult-classic {
	border: none !important;
}

.gs-spelling {
	a {
		color: @link-color !important;
	}
	a:hover,
	a:active,
	a:visited {
		color: @link-hover-color;
	}
}


//	Hide sidebar adds if we're on a phone (xs layout)
//
// This only seems to be consider on page generation (not on resizing)

.gsc-adBlockVertical {
	.hidden-xs();
}

// pagination at bottom
// copied and edited from pagination.less
.gsc-cursor-box {
	margin-bottom: 0;
	text-align: center !important;
}

.gsc-cursor {
  display: inline-block !important;
  padding-left: 0;
  margin: 0;
  border-radius: @border-radius-base;
}

.gsc-cursor-page {
    display: inline !important; // Remove list-style and block-level defaults

    position: relative;
    float: left; // Collapse white-space
    padding: @padding-base-vertical @padding-base-horizontal;
    line-height: @line-height-base;
    text-decoration: none !important;
    color: @pagination-color;
    background-color: @pagination-bg;
    border: 1px solid @pagination-border;
    margin-left: -1px;
	margin-right: 0 !important;

    &:first-child {
      margin-left: 0;
      .border-left-radius(@border-radius-base);
    }
    &:last-child {
      .border-right-radius(@border-radius-base);
    }

    &:hover,
    &:focus {
      color: @pagination-hover-color;
      background-color: @pagination-hover-bg;
      border-color: @pagination-hover-border;
    }
}

.gsc-cursor-current-page {
    &,
    &:hover,
    &:focus {
      z-index: 2;
      color: @pagination-active-color;
      background-color: @pagination-active-bg;
      border-color: @pagination-active-border;
      cursor: default;
    }
}
